# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Used by the EPIC CLI (https://github.com/zenotech/epic-cli).                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class PriceQuote(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cost': 'str',
        'ok': 'bool',
        'reason': 'str'
    }

    attribute_map = {
        'cost': 'cost',
        'ok': 'ok',
        'reason': 'reason'
    }

    def __init__(self, cost=None, ok=None, reason=None, local_vars_configuration=None):  # noqa: E501
        """PriceQuote - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cost = None
        self._ok = None
        self._reason = None
        self.discriminator = None

        if cost is not None:
            self.cost = cost
        if ok is not None:
            self.ok = ok
        if reason is not None:
            self.reason = reason

    @property
    def cost(self):
        """Gets the cost of this PriceQuote.  # noqa: E501

        The cost of the requested resource. May only be present if the ok field is true.  # noqa: E501

        :return: The cost of this PriceQuote.  # noqa: E501
        :rtype: str
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this PriceQuote.

        The cost of the requested resource. May only be present if the ok field is true.  # noqa: E501

        :param cost: The cost of this PriceQuote.  # noqa: E501
        :type cost: str
        """

        self._cost = cost

    @property
    def ok(self):
        """Gets the ok of this PriceQuote.  # noqa: E501

        Whether the requested spec represents a valid configuration that could be launched  # noqa: E501

        :return: The ok of this PriceQuote.  # noqa: E501
        :rtype: bool
        """
        return self._ok

    @ok.setter
    def ok(self, ok):
        """Sets the ok of this PriceQuote.

        Whether the requested spec represents a valid configuration that could be launched  # noqa: E501

        :param ok: The ok of this PriceQuote.  # noqa: E501
        :type ok: bool
        """

        self._ok = ok

    @property
    def reason(self):
        """Gets the reason of this PriceQuote.  # noqa: E501

        If the configuration is invalid this string will contain the reason why the configuration is not valid  # noqa: E501

        :return: The reason of this PriceQuote.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this PriceQuote.

        If the configuration is invalid this string will contain the reason why the configuration is not valid  # noqa: E501

        :param reason: The reason of this PriceQuote.  # noqa: E501
        :type reason: str
        """
        if (self.local_vars_configuration.client_side_validation and
                reason is not None and len(reason) > 100):
            raise ValueError("Invalid value for `reason`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reason is not None and len(reason) < 1):
            raise ValueError("Invalid value for `reason`, length must be greater than or equal to `1`")  # noqa: E501

        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PriceQuote):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PriceQuote):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Used by the EPIC CLI (https://github.com/zenotech/epic-cli).                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class FolderDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'folder_size': 'str',
        'created': 'datetime',
        'modified': 'datetime',
        'name': 'str',
        'obj_key': 'str',
        'last_modified': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'folder_size': 'folder_size',
        'created': 'created',
        'modified': 'modified',
        'name': 'name',
        'obj_key': 'obj_key',
        'last_modified': 'last_modified'
    }

    def __init__(self, id=None, folder_size=None, created=None, modified=None, name=None, obj_key=None, last_modified=None, local_vars_configuration=None):  # noqa: E501
        """FolderDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._folder_size = None
        self._created = None
        self._modified = None
        self._name = None
        self._obj_key = None
        self._last_modified = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if folder_size is not None:
            self.folder_size = folder_size
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if obj_key is not None:
            self.obj_key = obj_key
        self.last_modified = last_modified

    @property
    def id(self):
        """Gets the id of this FolderDetails.  # noqa: E501

        ID for this folder  # noqa: E501

        :return: The id of this FolderDetails.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FolderDetails.

        ID for this folder  # noqa: E501

        :param id: The id of this FolderDetails.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def folder_size(self):
        """Gets the folder_size of this FolderDetails.  # noqa: E501

        Folder size in bytes  # noqa: E501

        :return: The folder_size of this FolderDetails.  # noqa: E501
        :rtype: str
        """
        return self._folder_size

    @folder_size.setter
    def folder_size(self, folder_size):
        """Sets the folder_size of this FolderDetails.

        Folder size in bytes  # noqa: E501

        :param folder_size: The folder_size of this FolderDetails.  # noqa: E501
        :type folder_size: str
        """

        self._folder_size = folder_size

    @property
    def created(self):
        """Gets the created of this FolderDetails.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this FolderDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this FolderDetails.

        Creation time  # noqa: E501

        :param created: The created of this FolderDetails.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this FolderDetails.  # noqa: E501

        Last modified time  # noqa: E501

        :return: The modified of this FolderDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this FolderDetails.

        Last modified time  # noqa: E501

        :param modified: The modified of this FolderDetails.  # noqa: E501
        :type modified: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this FolderDetails.  # noqa: E501

        Folder name  # noqa: E501

        :return: The name of this FolderDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FolderDetails.

        Folder name  # noqa: E501

        :param name: The name of this FolderDetails.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def obj_key(self):
        """Gets the obj_key of this FolderDetails.  # noqa: E501

        S3 key reference  # noqa: E501

        :return: The obj_key of this FolderDetails.  # noqa: E501
        :rtype: str
        """
        return self._obj_key

    @obj_key.setter
    def obj_key(self, obj_key):
        """Sets the obj_key of this FolderDetails.

        S3 key reference  # noqa: E501

        :param obj_key: The obj_key of this FolderDetails.  # noqa: E501
        :type obj_key: str
        """
        if (self.local_vars_configuration.client_side_validation and
                obj_key is not None and len(obj_key) < 1):
            raise ValueError("Invalid value for `obj_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._obj_key = obj_key

    @property
    def last_modified(self):
        """Gets the last_modified of this FolderDetails.  # noqa: E501

        Last modified time  # noqa: E501

        :return: The last_modified of this FolderDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified

    @last_modified.setter
    def last_modified(self, last_modified):
        """Sets the last_modified of this FolderDetails.

        Last modified time  # noqa: E501

        :param last_modified: The last_modified of this FolderDetails.  # noqa: E501
        :type last_modified: datetime
        """

        self._last_modified = last_modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FolderDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FolderDetails):
            return True

        return self.to_dict() != other.to_dict()
